<?php
/* This file is part of the wp-monalisa plugin for wordpress */

/*  Copyright 2009-2018  Hans Matzen  (email : webmaster at tuxlog dot de)

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

//
// function to show an admin message on an admin page
//
if ( !function_exists('admin_message') )
{
	function admin_message($msg) {
		echo "<div class='updated'><p><strong>";
		echo $msg;
		echo "</strong></p></div>\n";
	}
}

//
// enqueue the wp-monalisa stylesheet individual or default
// if no individual exists
//
function wpml_css()
{
	$def  = "wp-monalisa-default.css";
	$user = "wp-monalisa.css";

	if (file_exists( WP_PLUGIN_DIR . "/wp-monalisa/" . $user))
		$def =$user;

	wp_enqueue_style("wp-monalisa", plugins_url( $def, __FILE__));
}

//
// the next functions are an adoption of wordpress 2.8 functions
// to change the behaviour as wanted for wp-monalisa
// thanks to all who worked on this.
//
// this functions maps the emoticons to icons
// and stores them in an global array
// it also prepares a global search pattern for all smilies
//
function wpml_map_emoticons()
{
	global $wpdb, $wpml_search, $wpml_smilies;

	$av=array();
	if (function_exists('is_multisite') && is_multisite()) {
		$av = maybe_unserialize(get_blog_option( get_current_blog_id(), "wpml-opts"));
	}  else
		$av = unserialize(get_option("wpml-opts"));

	// table name
	$wpml_table = $wpdb->prefix . "monalisa";

	//if (function_exists('is_multisite') && is_multisite())
	//	$wpml_table = $wpdb->base_prefix . "monalisa";

	// extend array allowedtags with img tag if necessary
	// to make sure the comment smilies dont geat lost
	if ( $av['replaceicon']==1)
	{
		global $allowedtags;
		if ( ! array_key_exists("img",$allowedtags) )
		{
			$allowedtags['img'] = array( 'src' => array(),
					'alt' => array(), 'class' => array(),
					'width' => array(), 'height' => array() );
		}
	}

	// select all valid smiley entries
	$sql="select tid,emoticon,iconfile,width,height from $wpml_table where oncomment=1 or onpost=1 order by tid;";
	$results = $wpdb->get_results($sql);

	// icon url begin including directory
	$ico_url = site_url($av['icondir']);

	foreach($results as $res)
	{
		// store emoticon mapping to array for smiley translation
		if ( ! array_key_exists($res->emoticon, $wpml_smilies) )
		{
			$wpml_smilies[ trim(wptexturize($res->emoticon)) ] = array(
					1 => $ico_url . "/" . $res->iconfile,
					2 => $res->width, 
					3 => $res->height);
		}

	}

	
	/*
	 * Taken from WP 4.7
	 * NOTE: we sort the smilies in reverse key order. This is to make sure
	 * we match the longest possible smilie (:???: vs :?) as the regular
	 * expression used below is first-match
	 */
	krsort($wpml_smilies);

	$spaces = wp_spaces_regexp();

	// Begin first "subpattern"
	$wpml_search = '/(?<=' . $spaces . '|^)';

	$subchar = '';
	foreach ( (array) $wpml_smilies as $smiley => $img ) {
		$firstchar = substr($smiley, 0, 1);
		$rest = substr($smiley, 1);

		// new subpattern?
		if ($firstchar != $subchar) {
			if ($subchar != '') {
				$wpml_search .= ')(?=' . $spaces . '|$)';  // End previous "subpattern"
				$wpml_search .= '|(?<=' . $spaces . '|^)'; // Begin another "subpattern"
			}
			$subchar = $firstchar;
			$wpml_search .= preg_quote($firstchar, '/') . '(?:';
		} else {
			$wpml_search .= '|';
		}
		$wpml_search .= preg_quote($rest, '/');
	}

	$wpml_search .= ')(?=' . $spaces . '|$)/m';

	if ( count($wpml_smilies) == 0 )
		$wpml_search="";
}

//
// translate an emoticon into a valid img tag
//
function wpml_translate_emoticon($smiley) {
	global $wpml_smilies;

	if (count($smiley) == 0) {
		return '';
	}

	$smiley = trim(reset($smiley));
	$img = $wpml_smilies[$smiley][1];
	$width = $wpml_smilies[$smiley][2];
	$height = $wpml_smilies[$smiley][3];
	$smiley_masked = esc_attr($smiley);

	return " <img src='$img' alt='$smiley_masked' width='$width' height='$height' class='wpml_ico' /> ";
}


//
// convert emoticons to icons in img tags
//
function wpml_convert_emoticons($text)
{ 
	global $wpml_search;

	// no smilies to change, return original text
	if ( empty($wpml_search) )
		return $text;

	// reset output
	$output = '';

	// taken from wordpress 2.8
	$textarr = preg_split("/(<.*>)/U", $text, -1, PREG_SPLIT_DELIM_CAPTURE);
	// capture the tags as well as in between
	$stop = count($textarr);// loop stuff
	for ($i = 0; $i < $stop; $i++) {
		$content = $textarr[$i];

		if ((strlen(trim($content)) > 0) ) {
		//    	  && ('<' != $content{0})) {

			//If it's not a tag
			$content = preg_replace_callback($wpml_search,
					'wpml_translate_emoticon',
					$content);
			 
		}
		$output .= $content;
	}
	return $output;
}

// php4 compatibility functions
//
// rebuilds the scandir function not available with php4
// copied from Cory S.N. LaViska, thank you :-)
//
if( !function_exists('scandir') ) {
	function scandir($directory, $sorting_order = 0) {
		$dh  = @opendir($directory);
		$files=array();

		if ($dh)
		{
			while( false !== ($filename = readdir($dh)) ) {
				$files[] = $filename;
			}
			if( $sorting_order == 0 ) {
				sort($files);
			} else {
				rsort($files);
			}
		}
		return($files);
	}
}

//
// Funktion zum aktualisieren der Höhe und Breite Einträge in der wp_monaslisa Tabelle
//
// hoehe und breite fuer vorhandene eintraege setzen
//
function set_dimensions($av) {
	global $wpdb;
	$sql = "select tid, iconfile from ".$wpdb->prefix."monalisa where width=0 or height=0;";
	$results = $wpdb->get_results($sql);

	foreach($results as $res)
	{
		// breite und hoehe ermitteln
		$isize=getimagesize(ABSPATH . $av['icondir'] . "/" . $res->iconfile);
		$breite=$isize[0];
		$hoehe=$isize[1];

		$usql = "update ".$wpdb->prefix."monalisa set width=$breite, height=$hoehe where tid=". $res->tid;
		$results = $wpdb->query($usql);
	}
}

function wpml_get_richedit_smilies() {
    global $wpdb;

    // table name
    $wpml_table = $wpdb->prefix . "monalisa";

    //if (function_exists('is_multisite') && is_multisite()) 
	//	$wpml_table = $wpdb->base_prefix . "monalisa";

    // optionen einlesen
    $av = unserialize(get_option("wpml-opts"));

    // in case we are on a multisite try get the settings from blog no one
    if ($av == false)
		$av = unserialize(get_blog_option(get_current_blog_id(), "wpml-opts"));

    // icons lesen
    if (is_admin())
		$sql="select tid,emoticon,iconfile from $wpml_table where onpost=1 order by tid;";
	else
		$sql="select tid,emoticon,iconfile from $wpml_table where oncomment=1 order by tid;";
    $results = $wpdb->get_results($sql);
    
        
    $resmilies=array();
    $double_check = array(); // array um doppelte auszuschliessen

    foreach($results as $res) {
		// prüfe ob icon schon ausgegeben, 
		// wenn ja überspringe es, 
		// wenn nein merken
		if ( in_array($res->iconfile, $double_check) )
			continue;
		else
			$double_check[] = $res->iconfile;

		$ico_url = site_url($av['icondir']) . '/' . $res->iconfile; 
	
		$resmilies[] = array( $res->tid, trim($res->emoticon), $ico_url );
	}
	
	return $resmilies;
}
?>